@@ -1,9 +1,8 @@
 from django.apps import AppConfig
+from django.utils.translation import gettext_lazy as _
 
 
 class AnalyticsConfig(AppConfig):
     name = 'allianceauth.analytics'
     label = 'analytics'
-
-    def ready(self):
-        import allianceauth.analytics.signals
+    verbose_name = _('Analytics')
