@@ -288,7 +288,7 @@ class UserAdmin(BaseUserAdmin):
     Behavior of groups and characters columns can be configured via settings
     """
 
-    inlines = BaseUserAdmin.inlines + [UserProfileInline]
+    inlines = [UserProfileInline]
     ordering = ('username', )
     list_select_related = ('profile__state', 'profile__main_character')
     show_full_result_count = True
