@@ -2,7 +2,6 @@ import logging
 
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User, Permission
-from django.contrib import messages
 
 from .models import UserProfile, CharacterOwnership, OwnershipRecord
 
@@ -41,9 +40,7 @@ class StateBackend(ModelBackend):
                 if ownership.user.profile.main_character:
                     if ownership.user.profile.main_character.character_id == token.character_id:
                         return ownership.user
-                    else:  ## this is an alt, enforce main only.
-                        if request:
-                            messages.error("Unable to authenticate with this Character, Please log in with the main character associated with this account.")
+                    else:  # this is an alt, enforce main only.
                         return None
             else:
                 logger.debug(f'{token.character_name} has changed ownership. Creating new user account.')
@@ -65,10 +62,8 @@ class StateBackend(ModelBackend):
                     # we've seen this character owner before. Re-attach to their old user account
                     user = records[0].user
                     if user.profile.main_character:
-                        if ownership.user.profile.main_character.character_id != token.character_id:
-                            ## this is an alt, enforce main only due to trust issues in SSO.
-                            if request:
-                                messages.error("Unable to authenticate with this Character, Please log in with the main character associated with this account. Then add this character from the dashboard.")
+                        if user.profile.main_character.character_id != token.character_id:
+                            # this is an alt, enforce main only due to trust issues in SSO.
                             return None
 
                     token.user = user
