@@ -31,6 +31,7 @@ class UserSettingsMiddleware(MiddlewareMixin):
             except Exception as e:
                 logger.exception(e)
 
+            # AA v3 NIGHT_MODE
             # Set our Night mode flag from the DB
             # Null = hasnt been set by the user ever, dont act.
             #
@@ -42,4 +43,19 @@ class UserSettingsMiddleware(MiddlewareMixin):
             except Exception as e:
                 logger.exception(e)
 
+            # AA v4 Themes
+            # Null = has not been set by the user ever, dont act
+            # DEFAULT_THEME or DEFAULT_THEME_DARK will be used in get_theme()
+            try:
+                if request.user.profile.theme is not None:
+                    request.session["THEME"] = request.user.profile.theme
+            except Exception as e:
+                logger.exception(e)
+
+        # Minimize Menu
+        try:
+            request.session["MINIMIZE_SIDEBAR"] = request.user.profile.minimize_sidebar
+        except Exception as e:
+            pass  # We don't care that an anonymous user has no profile (not logged in)
+
         return response
