@@ -1,4 +1,5 @@
 import logging
+from typing import ClassVar
 
 from django.contrib.auth.models import User, Permission
 from django.db import models, transaction
@@ -27,7 +28,7 @@ class State(models.Model):
                                             help_text="Factions to whose members this state is available.")
     public = models.BooleanField(default=False, help_text="Make this state available to any character.")
 
-    objects = StateManager()
+    objects: ClassVar[StateManager] = StateManager()
 
     class Meta:
         ordering = ['-priority']
@@ -63,6 +64,25 @@ class UserProfile(models.Model):
     class Meta:
         default_permissions = ('change',)
 
+    class Language(models.TextChoices):
+        """
+        Choices for UserProfile.language
+        """
+        # Sorted by Language Code alphabetical order + English at top
+        ENGLISH = 'en', _('English')
+        CZECH = 'cs-cz', _("Czech")  # Not yet at 50% translated
+        GERMAN = 'de', _('German')
+        SPANISH = 'es', _('Spanish')
+        ITALIAN = 'it-it', _('Italian')
+        JAPANESE = 'ja', _('Japanese')
+        KOREAN = 'ko-kr', _('Korean')
+        FRENCH = 'fr-fr', _('French')
+        RUSSIAN = 'ru', _('Russian')
+        DUTCH = 'nl-nl', _("Dutch")
+        POLISH = 'pl-pl', _("Polish")
+        UKRAINIAN = 'uk', _('Ukrainian')
+        CHINESE = 'zh-hans', _('Simplified Chinese')
+
     user = models.OneToOneField(
         User,
         related_name='profile',
@@ -76,26 +96,29 @@ class UserProfile(models.Model):
         State,
         on_delete=models.SET_DEFAULT,
         default=get_guest_state_pk)
-    LANGUAGE_CHOICES = [
-        ('en', _('English')),
-        ('de', _('German')),
-        ('es', _('Spanish')),
-        ('zh-hans', _('Chinese Simplified')),
-        ('ru', _('Russian')),
-        ('ko', _('Korean')),
-        ('fr', _('French')),
-        ('ja', _('Japanese')),
-        ('it', _('Italian')),
-    ]
     language = models.CharField(
-        _("Language"), max_length=10,
-        choices=LANGUAGE_CHOICES,
+        _("Language"),
+        max_length=10,
+        choices=Language.choices,
         blank=True,
         default='')
     night_mode = models.BooleanField(
         _("Night Mode"),
         blank=True,
         null=True)
+    theme = models.CharField(
+        _("Theme"),
+        max_length=200,
+        blank=True,
+        null=True,
+        help_text="Bootstrap 5 Themes from https://bootswatch.com/ or Community Apps"
+    )
+    minimize_sidebar = models.BooleanField(
+        _("Minimize Sidebar Menu"),
+        default=False,
+        help_text=_("Keep the sidebar menu minimized")
+    )
+
 
     def assign_state(self, state=None, commit=True):
         if not state:
@@ -122,8 +145,10 @@ class UserProfile(models.Model):
                     sender=self.__class__, user=self.user, state=self.state
                 )
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self.user)
+
+
 class CharacterOwnership(models.Model):
     class Meta:
         default_permissions = ('change', 'delete')
@@ -133,7 +158,7 @@ class CharacterOwnership(models.Model):
     owner_hash = models.CharField(max_length=28, unique=True)
     user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='character_ownerships')
 
-    objects = CharacterOwnershipManager()
+    objects: ClassVar[CharacterOwnershipManager] = CharacterOwnershipManager()
 
     def __str__(self):
         return f"{self.user}: {self.character}"
