@@ -1,35 +1,39 @@
 import logging
 
+import requests
+from django_registration.backends.activation.views import (
+    REGISTRATION_SALT, ActivationView as BaseActivationView,
+    RegistrationView as BaseRegistrationView,
+)
+from django_registration.signals import user_registered
+
 from django.conf import settings
 from django.contrib import messages
-from django.contrib.auth import login, authenticate
-from django.contrib.auth.decorators import login_required
+from django.contrib.auth import authenticate, login
+from django.contrib.auth.decorators import login_required, user_passes_test
 from django.contrib.auth.models import User
 from django.core import signing
-from django.core.mail import EmailMultiAlternatives
 from django.http import JsonResponse
 from django.shortcuts import redirect, render
 from django.template.loader import render_to_string
 from django.urls import reverse, reverse_lazy
 from django.utils.translation import gettext_lazy as _
 
-from allianceauth.eveonline.models import EveCharacter
 from esi.decorators import token_required
 from esi.models import Token
 
-from django_registration.backends.activation.views import (
-    RegistrationView as BaseRegistrationView,
-    ActivationView as BaseActivationView,
-    REGISTRATION_SALT
-)
-from django_registration.signals import user_registered
+from allianceauth.eveonline.models import EveCharacter
+from allianceauth.hooks import get_hooks
 
-from .models import CharacterOwnership
+from .constants import ESI_ERROR_MESSAGE_OVERRIDES
+from .core.celery_workers import active_tasks_count, queued_tasks_count
+from allianceauth.templatetags.admin_status import _celery_stats
 from .forms import RegistrationForm
+from .models import CharacterOwnership
 
 if 'allianceauth.eveonline.autogroups' in settings.INSTALLED_APPS:
     _has_auto_groups = True
-    from allianceauth.eveonline.autogroups.models import *
+    from allianceauth.eveonline.autogroups.models import *  # noqa: F401, F403
 else:
     _has_auto_groups = False
 
@@ -42,25 +46,61 @@ def index(request):
     return redirect('authentication:dashboard')
 
 
-@login_required
-def dashboard(request):
+def dashboard_groups(request):
     groups = request.user.groups.all()
     if _has_auto_groups:
         groups = groups\
             .filter(managedalliancegroup__isnull=True)\
             .filter(managedcorpgroup__isnull=True)
     groups = groups.order_by('name')
+
+    context = {
+        'groups': groups,
+    }
+    return render_to_string('authentication/dashboard_groups.html', context=context, request=request)
+
+
+def dashboard_characters(request):
     characters = EveCharacter.objects\
         .filter(character_ownership__user=request.user)\
         .select_related()\
         .order_by('character_name')
 
     context = {
-        'groups': groups,
         'characters': characters
     }
+    return render_to_string('authentication/dashboard_characters.html', context=context, request=request)
+
+
+def dashboard_admin(request):
+    if request.user.is_superuser:
+        return render_to_string('allianceauth/admin-status/include.html', request=request)
+    else:
+        return ""
+
+
+def dashboard_esi_check(request):
+    if request.user.is_superuser:
+        return render_to_string('allianceauth/admin-status/esi_check.html', request=request)
+    else:
+        return ""
+
+
+@login_required
+def dashboard(request):
+    _dash_items = list()
+    hooks = get_hooks('dashboard_hook')
+    items = [fn() for fn in hooks]
+    items.sort(key=lambda i: i.order)
+    for item in items:
+        _dash_items.append(item.render(request))
+
+    context = {
+        'views': _dash_items,
+    }
     return render(request, 'authentication/dashboard.html', context)
 
+
 @login_required
 def token_management(request):
     tokens = request.user.token_set.all()
@@ -70,6 +110,7 @@ def token_management(request):
     }
     return render(request, 'authentication/tokens.html', context)
 
+
 @login_required
 def token_delete(request, token_id=None):
     try:
@@ -83,6 +124,7 @@ def token_delete(request, token_id=None):
         messages.warning(request, "Token does not exist")
     return redirect('authentication:token_management')
 
+
 @login_required
 def token_refresh(request, token_id=None):
     try:
@@ -103,23 +145,30 @@ def token_refresh(request, token_id=None):
 @login_required
 @token_required(scopes=settings.LOGIN_TOKEN_SCOPES)
 def main_character_change(request, token):
-    logger.debug(f"main_character_change called by user {request.user} for character {token.character_name}")
+    logger.debug(
+        f"main_character_change called by user {request.user} for character {token.character_name}")
     try:
-        co = CharacterOwnership.objects.get(character__character_id=token.character_id, user=request.user)
+        co = CharacterOwnership.objects.get(
+            character__character_id=token.character_id, user=request.user)
     except CharacterOwnership.DoesNotExist:
         if not CharacterOwnership.objects.filter(character__character_id=token.character_id).exists():
             co = CharacterOwnership.objects.create_by_token(token)
         else:
             messages.error(
                 request,
-                _('Cannot change main character to %(char)s: character owned by a different account.') % ({'char': token.character_name})
+                _('Cannot change main character to %(char)s: character owned by a different account.') % (
+                    {'char': token.character_name})
             )
             co = None
     if co:
         request.user.profile.main_character = co.character
         request.user.profile.save(update_fields=['main_character'])
-        messages.success(request, _('Changed main character to %(char)s') % {"char": co.character})
-        logger.info('Changed user %(user)s main character to %(char)s' % ({'user': request.user, 'char': co.character}))
+        messages.success(request, _('Changed main character to %s') % co.character)
+        logger.info(
+            'Changed user {user} main character to {char}'.format(
+                user=request.user, char=co.character
+            )
+        )
     return redirect("authentication:dashboard")
 
 
@@ -127,9 +176,11 @@ def main_character_change(request, token):
 def add_character(request, token):
     if CharacterOwnership.objects.filter(character__character_id=token.character_id).filter(
             owner_hash=token.character_owner_hash).filter(user=request.user).exists():
-        messages.success(request, _('Added %(name)s to your account.'% ({'name': token.character_name})))
+        messages.success(request, _(
+            'Added %(name)s to your account.' % ({'name': token.character_name})))
     else:
-        messages.error(request, _('Failed to add %(name)s to your account: they already have an account.' % ({'name': token.character_name})))
+        messages.error(request, _('Failed to add %(name)s to your account: they already have an account.' % (
+            {'name': token.character_name})))
     return redirect('authentication:dashboard')
 
 
@@ -168,7 +219,15 @@ def sso_login(request, token):
             request.session['registration_uid'] = user.pk
             # Go to Step 2
             return redirect('registration_register')
-    messages.error(request, _('Unable to authenticate as the selected character.'))
+    # Logging in with an alt is not allowed due to security concerns.
+    token.delete()
+    messages.error(
+        request,
+        _(
+            'Unable to authenticate as the selected character. '
+            'Please log in with the main character associated with this account.'
+        )
+    )
     return redirect(settings.LOGIN_URL)
 
 
@@ -240,7 +299,8 @@ class RegistrationView(BaseRegistrationView):
         return super().dispatch(request, *args, **kwargs)
 
     def register(self, form):
-        user = User.objects.get(pk=self.request.session.get('registration_uid'))
+        user = User.objects.get(
+            pk=self.request.session.get('registration_uid'))
         user.email = form.cleaned_data['email']
         user_registered.send(self.__class__, user=user, request=self.request)
         if getattr(settings, 'REGISTRATION_VERIFY_EMAIL', True):
@@ -257,7 +317,8 @@ class RegistrationView(BaseRegistrationView):
 
     def get_email_context(self, activation_key):
         context = super().get_email_context(activation_key)
-        context['url'] = context['site'].domain + reverse('registration_activate', args=[activation_key])
+        context['url'] = context['site'].domain + \
+            reverse('registration_activate', args=[activation_key])
         return context
 
 
@@ -268,8 +329,11 @@ class ActivationView(BaseActivationView):
 
     def validate_key(self, activation_key):
         try:
-            dump = signing.loads(activation_key, salt=REGISTRATION_SALT,
-                                max_age=settings.ACCOUNT_ACTIVATION_DAYS * 86400)
+            dump = signing.loads(
+                activation_key,
+                salt=REGISTRATION_SALT,
+                max_age=settings.ACCOUNT_ACTIVATION_DAYS * 86400
+            )
             return dump
         except signing.BadSignature:
             return None
@@ -287,15 +351,56 @@ class ActivationView(BaseActivationView):
 
 
 def registration_complete(request):
-    messages.success(request, _('Sent confirmation email. Please follow the link to confirm your email address.'))
+    messages.success(request, _(
+        'Sent confirmation email. Please follow the link to confirm your email address.'))
     return redirect('authentication:login')
 
 
 def activation_complete(request):
-    messages.success(request, _('Confirmed your email address. Please login to continue.'))
+    messages.success(request, _(
+        'Confirmed your email address. Please login to continue.'))
     return redirect('authentication:dashboard')
 
 
 def registration_closed(request):
-    messages.error(request, _('Registration of new accounts is not allowed at this time.'))
+    messages.error(request, _(
+        'Registration of new accounts is not allowed at this time.'))
     return redirect('authentication:login')
+
+
+@user_passes_test(lambda u: u.is_superuser)
+def task_counts(request) -> JsonResponse:
+    """Return task counts as JSON for an AJAX call."""
+    data = _celery_stats()
+    data.update(
+        {"tasks_running": active_tasks_count(), "tasks_queued": queued_tasks_count()}
+    )
+    return JsonResponse(data)
+
+
+def check_for_override_esi_error_message(response):
+    if response.status_code in ESI_ERROR_MESSAGE_OVERRIDES:
+        return {"error": ESI_ERROR_MESSAGE_OVERRIDES.get(response.status_code)}
+    else:
+        return response.json()
+
+
+@user_passes_test(lambda u: u.is_superuser)
+def esi_check(request) -> JsonResponse:
+    """Return if ESI ok With error messages and codes as JSON"""
+    _r = requests.get("https://esi.evetech.net/latest/status/?datasource=tranquility")
+
+    data = {
+        "status": _r.status_code,
+        "data": check_for_override_esi_error_message(_r)
+    }
+    return JsonResponse(data)
+
+
+@login_required
+def dashboard_bs3(request):
+    """Render dashboard view with BS3 theme.
+
+    This is an internal view used for testing BS3 backward compatibility in AA4 only.
+    """
+    return render(request, 'authentication/dashboard_bs3.html')
