@@ -1,4 +1,5 @@
-from allianceauth.services.hooks import MenuItemHook, UrlHook
+from allianceauth.menu.hooks import MenuItemHook
+from allianceauth.services.hooks import UrlHook
 from django.utils.translation import gettext_lazy as _
 from allianceauth import hooks
 from allianceauth.corputils import urls
@@ -9,7 +10,7 @@ class CorpStats(MenuItemHook):
         MenuItemHook.__init__(
             self,
             _('Corporation Stats'),
-            'fas fa-share-alt fa-fw',
+            'fa-solid fa-share-nodes',
             'corputils:view',
             navactive=['corputils:']
         )
