@@ -1,4 +1,5 @@
 import logging
+from typing import ClassVar
 from django.db import models, transaction
 from django.contrib.auth.models import Group, User
 from django.core.exceptions import ObjectDoesNotExist
@@ -26,7 +27,7 @@ class AutogroupsConfigManager(models.Manager):
         for config in self.filter(states=state):
             logger.debug("in state loop")
             for user in users:
-                logger.debug("in user loop for {}".format(user))
+                logger.debug(f"in user loop for {user}")
                 config.update_group_membership_for_user(user)
 
     def update_groups_for_user(self, user: User, state: State = None):
@@ -38,13 +39,13 @@ class AutogroupsConfigManager(models.Manager):
         """
         if state is None:
             state = user.profile.state
-        for config in self.filter(states=state):
-            # grant user new groups for their state
-            config.update_group_membership_for_user(user)
         for config in self.exclude(states=state):
             # ensure user does not have groups from previous state
             config.remove_user_from_alliance_groups(user)
             config.remove_user_from_corp_groups(user)
+        for config in self.filter(states=state):
+            # grant user new groups for their state
+            config.update_group_membership_for_user(user)
 
 
 class AutogroupsConfig(models.Model):
@@ -57,35 +58,31 @@ class AutogroupsConfig(models.Model):
 
     states = models.ManyToManyField(State, related_name='autogroups')
 
-    corp_groups = models.BooleanField(default=False,
-                                      help_text="Setting this to false will delete all the created groups.")
+    corp_groups = models.BooleanField(default=False, help_text="Setting this to false will delete all the created groups.")
     corp_group_prefix = models.CharField(max_length=50, default='Corp ', blank=True)
     corp_name_source = models.CharField(max_length=20, choices=NAME_OPTIONS, default=OPT_NAME)
 
-    alliance_groups = models.BooleanField(default=False,
-                                          help_text="Setting this to false will delete all the created groups.")
+    alliance_groups = models.BooleanField(default=False, help_text="Setting this to false will delete all the created groups.")
     alliance_group_prefix = models.CharField(max_length=50, default='Alliance ', blank=True)
     alliance_name_source = models.CharField(max_length=20, choices=NAME_OPTIONS, default=OPT_NAME)
 
     corp_managed_groups = models.ManyToManyField(
         Group, through='ManagedCorpGroup', related_name='corp_managed_config',
-        help_text='A list of corporation groups created and maintained by this AutogroupConfig. '
-                  'You should not edit this list unless you know what you\'re doing.')
+        help_text='A list of corporation groups created and maintained by this AutogroupConfig. You should not edit this list unless you know what you\'re doing.')
 
     alliance_managed_groups = models.ManyToManyField(
         Group, through='ManagedAllianceGroup', related_name='alliance_managed_config',
-        help_text='A list of alliance groups created and maintained by this AutogroupConfig. '
-                  'You should not edit this list unless you know what you\'re doing.')
+        help_text='A list of alliance groups created and maintained by this AutogroupConfig. You should not edit this list unless you know what you\'re doing.')
 
     replace_spaces = models.BooleanField(default=False)
     replace_spaces_with = models.CharField(
         max_length=10, default='', blank=True,
         help_text='Any spaces in the group name will be replaced with this.')
 
-    objects = AutogroupsConfigManager()
+    objects: ClassVar[AutogroupsConfigManager] = AutogroupsConfigManager()
 
     def __init__(self, *args, **kwargs):
-        super(AutogroupsConfig, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def __repr__(self):
         return self.__class__.__name__
@@ -115,24 +112,24 @@ class AutogroupsConfig(models.Model):
         group = None
         try:
             if not self.alliance_groups or not self.user_entitled_to_groups(user):
-                logger.debug('User {} does not have required state for alliance group membership'.format(user))
+                logger.debug(f'User {user} does not have required state for alliance group membership')
                 return
             else:
                 alliance = user.profile.main_character.alliance
                 if alliance is None:
-                    logger.debug('User {} alliance is None, cannot update group membership'.format(user))
+                    logger.debug(f'User {user} alliance is None, cannot update group membership')
                     return
                 group = self.get_alliance_group(alliance)
         except EveAllianceInfo.DoesNotExist:
-            logger.debug('User {} main characters alliance does not exist in the database. Creating.'.format(user))
+            logger.debug(f'User {user} main characters alliance does not exist in the database. Creating.')
             alliance = EveAllianceInfo.objects.create_alliance(user.profile.main_character.alliance_id)
             group = self.get_alliance_group(alliance)
         except AttributeError:
-            logger.warning('User {} does not have a main character. Group membership not updated'.format(user))
+            logger.warning(f'User {user} does not have a main character. Group membership not updated')
         finally:
             self.remove_user_from_alliance_groups(user, except_group=group)
             if group is not None:
-                logger.debug('Adding user {} to alliance group {}'.format(user, group))
+                logger.debug(f'Adding user {user} to alliance group {group}')
                 user.groups.add(group)
 
     @transaction.atomic
@@ -140,20 +137,20 @@ class AutogroupsConfig(models.Model):
         group = None
         try:
             if not self.corp_groups or not self.user_entitled_to_groups(user):
-                logger.debug('User {} does not have required state for corp group membership'.format(user))
+                logger.debug(f'User {user} does not have required state for corp group membership')
             else:
                 corp = user.profile.main_character.corporation
                 group = self.get_corp_group(corp)
         except EveCorporationInfo.DoesNotExist:
-            logger.debug('User {} main characters corporation does not exist in the database. Creating.'.format(user))
+            logger.debug(f'User {user} main characters corporation does not exist in the database. Creating.')
             corp = EveCorporationInfo.objects.create_corporation(user.profile.main_character.corporation_id)
             group = self.get_corp_group(corp)
         except AttributeError:
-            logger.warning('User {} does not have a main character. Group membership not updated'.format(user))
+            logger.warning(f'User {user} does not have a main character. Group membership not updated')
         finally:
             self.remove_user_from_corp_groups(user, except_group=group)
             if group is not None:
-                logger.debug('Adding user {} to corp group {}'.format(user, group))
+                logger.debug(f'Adding user {user} to corp group {group}')
                 user.groups.add(group)
 
     @transaction.atomic
