@@ -1,3 +1,4 @@
+from allianceauth.eveonline.models import EveCorporationInfo
 from django.test import TestCase
 from allianceauth.tests.auth_utils import AuthUtils
 
@@ -73,3 +74,51 @@ class AutogroupsConfigManagerTestCase(TestCase):
         AutogroupsConfig.objects.update_groups_for_user(member)
 
         self.assertTrue(update_groups.called)
+
+    def test_update_group_membership_corp_in_two_configs(self):
+        # given
+        member = AuthUtils.create_member('test member')
+        AuthUtils.add_main_character_2(
+            member,
+            character_id='1234',
+            name='test character',
+            corp_id='2345',
+            corp_name='corp name',
+            corp_ticker='TIKK',
+
+        )
+
+        corp = EveCorporationInfo.objects.create(
+            corporation_id='2345',
+            corporation_name='corp name',
+            corporation_ticker='TIKK',
+            member_count=10,
+        )
+
+        member_state = AuthUtils.get_member_state()
+        member_config = AutogroupsConfig.objects.create(corp_groups=True)
+        member_config.states.add(member_state)
+        blue_state = AuthUtils.get_blue_state()
+        blue_state.member_corporations.add(corp)
+        blue_config = AutogroupsConfig.objects.create(corp_groups=True)
+        blue_config.states.add(blue_state)
+
+        member.profile.state = blue_state
+        member.profile.save()
+
+        AutogroupsConfig.objects.update_groups_for_user(member)
+
+        # Checks before test that the role is correctly applied
+        group = blue_config.get_corp_group(corp)
+        self.assertIn(group, member.groups.all())
+
+        # when
+        blue_state.member_corporations.remove(corp)
+        member_state.member_corporations.add(corp)
+        member.profile.state = member_state
+        member.profile.save()
+
+        # then
+        AutogroupsConfig.objects.update_groups_for_user(member)
+        group = member_config.get_corp_group(corp)
+        self.assertIn(group, member.groups.all())
