@@ -10,7 +10,7 @@ from . import (
 )
 
 
-_BASE_URL = 'http://evemaps.dotlan.net'
+_BASE_URL = 'https://evemaps.dotlan.net'
 
 
 def _build_url(category: str, name: str) -> str:
