@@ -14,10 +14,20 @@ class EveCharacterProviderManager:
 class EveCharacterManager(models.Manager):
     provider = EveCharacterProviderManager()
 
-    def create_character(self, character_id):
+    def exclude_biomassed(self):
+        """
+        Get a queryset of EveCharacter objects, excluding the "Doomheim" corporation (1000001).
+
+        :return:
+        :rtype:
+        """
+
+        return self.exclude(corporation_id=1000001)
+
+    def create_character(self, character_id) -> models.Model:
         return self.create_character_obj(self.provider.get_character(character_id))
 
-    def create_character_obj(self, character: providers.Character):
+    def create_character_obj(self, character: providers.Character) -> models.Model:
         return self.create(
             character_id=character.id,
             character_name=character.name,
@@ -27,15 +37,19 @@ class EveCharacterManager(models.Manager):
             alliance_id=character.alliance.id,
             alliance_name=character.alliance.name,
             alliance_ticker=getattr(character.alliance, 'ticker', None),
+            faction_id=character.faction.id,
+            faction_name=character.faction.name
         )
 
     def update_character(self, character_id):
         return self.get(character_id=character_id).update_character()
 
-    def get_character_by_id(self, char_id):
-        if self.filter(character_id=char_id).exists():
-            return self.get(character_id=char_id)
-        return None
+    def get_character_by_id(self, character_id: int):
+        """Return character by character ID or None if not found."""
+        try:
+            return self.get(character_id=character_id)
+        except self.model.DoesNotExist:
+            return None
 
 
 class EveAllianceProviderManager:
