@@ -7,7 +7,8 @@ from jsonschema.exceptions import RefResolutionError
 from django.conf import settings
 from esi.clients import esi_client_factory
 
-from allianceauth import __version__
+from allianceauth import __version__, __title_useragent__, __url__
+from allianceauth.utils.django import StartupCommand
 
 
 SWAGGER_SPEC_PATH = os.path.join(os.path.dirname(
@@ -175,15 +176,18 @@ class EveProvider:
 
 class EveSwaggerProvider(EveProvider):
     def __init__(self, token=None, adapter=None):
-        if settings.DEBUG:
+        if settings.DEBUG or StartupCommand().is_management_command:
             self._client = None
-            logger.info(
-                'DEBUG mode detected: ESI client will be loaded on-demand.'
-            )
+            logger.info('ESI client will be loaded on-demand')
         else:
+            logger.info('Loading ESI client')
             try:
                 self._client = esi_client_factory(
-                    token=token, spec_file=SWAGGER_SPEC_PATH, app_info_text=("allianceauth v" + __version__)
+                    token=token,
+                    spec_file=SWAGGER_SPEC_PATH,
+                    ua_appname=__title_useragent__,
+                    ua_version=__version__,
+                    ua_url=__url__
                 )
             except (HTTPError, RefResolutionError):
                 logger.exception(
@@ -200,7 +204,11 @@ class EveSwaggerProvider(EveProvider):
     def client(self):
         if self._client is None:
             self._client = esi_client_factory(
-                token=self._token, spec_file=SWAGGER_SPEC_PATH, app_info_text=("allianceauth v" + __version__)
+                token=self._token,
+                spec_file=SWAGGER_SPEC_PATH,
+                ua_appname=__title_useragent__,
+                ua_version=__version__,
+                ua_url=__url__
             )
         return self._client
 
