@@ -320,8 +320,8 @@ def click_fatlink_view(request, token, fat_hash=None):
         messages.warning(
             request,
             _(
-                f"Cannot register the fleet participation for {character.character_name}. The character needs to be online."
-            ),
+                "Cannot register the fleet participation for {character_name}. The character needs to be online."
+            ).format(character_name=character.character_name)
         )
 
     return redirect('fatlink:view')
@@ -352,11 +352,11 @@ def create_fatlink_view(request):
                     for errorname, message in e.message_dict.items():
                         messages.append(message[0].decode())
                     context = {'form': form, 'errormessages': messages}
-                    return render(request, 'fleetactivitytracking/fatlinkformatter.html', context=context)
+                    return render(request, 'fleetactivitytracking/fatlinkcreate.html', context=context)
             else:
                 form = FatlinkForm()
                 context = {'form': form, 'badrequest': True}
-                return render(request, 'fleetactivitytracking/fatlinkformatter.html', context=context)
+                return render(request, 'fleetactivitytracking/fatlinkcreate.html', context=context)
             return redirect('fatlink:view')
 
     else:
@@ -365,7 +365,7 @@ def create_fatlink_view(request):
 
     context = {'form': form}
 
-    return render(request, 'fleetactivitytracking/fatlinkformatter.html', context=context)
+    return render(request, 'fleetactivitytracking/fatlinkcreate.html', context=context)
 
 
 @login_required
@@ -377,12 +377,12 @@ def modify_fatlink_view(request, fat_hash=None):
     if request.GET.get('removechar', None):
         character_id = request.GET.get('removechar')
         character = EveCharacter.objects.get(character_id=character_id)
-        logger.debug(f"Removing character {character.character_name} from fleetactivitytracking  {fatlink}")
+        logger.debug(f"Removing character {character.character_name} from fleetactivitytracking {fatlink}")
 
         Fat.objects.filter(fatlink=fatlink).filter(character=character).delete()
 
     if request.GET.get('deletefat', None):
-        logger.debug("Removing fleetactivitytracking  %s" % fatlink)
+        logger.debug("Removing fleetactivitytracking %s" % fatlink)
         fatlink.delete()
         return redirect('fatlink:view')
 
