@@ -5,11 +5,16 @@ app_name = "groupmanagement"
 
 urlpatterns = [
     # groups
-    path("groups", views.groups_view, name="groups"),
+    path("groups/", views.groups_view, name="groups"),
     path("group/request/join/<int:group_id>/", views.group_request_add, name="request_add"),
     path(
         "group/request/leave/<int:group_id>/", views.group_request_leave, name="request_leave"
     ),
+    path(
+        "group/request/retract/<int:group_id>/",
+        views.group_request_retract,
+        name="request_retract"
+    ),
     # group management
     path("groupmanagement/requests/", views.group_management, name="management"),
     path("groupmanagement/membership/", views.group_membership, name="membership"),
