@@ -2,13 +2,12 @@ import logging
 
 from django.conf import settings
 from django.contrib import messages
-from django.contrib.auth.decorators import login_required
-from django.contrib.auth.decorators import user_passes_test
+from django.contrib.auth.decorators import login_required, user_passes_test
 from django.contrib.auth.models import Group
 from django.core.exceptions import ObjectDoesNotExist, PermissionDenied
 from django.db.models import Count
 from django.http import Http404
-from django.shortcuts import render, redirect, get_object_or_404
+from django.shortcuts import get_object_or_404, redirect, render
 from django.utils.translation import gettext_lazy as _
 
 from allianceauth.notifications import notify
@@ -16,7 +15,6 @@ from allianceauth.notifications import notify
 from .managers import GroupManager
 from .models import GroupRequest, RequestLog
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -45,10 +43,15 @@ def group_management(request):
     logger.debug("Providing user {} with {} acceptrequests and {} leaverequests.".format(
         request.user, len(acceptrequests), len(leaverequests)))
 
+    show_leave_tab = (
+        getattr(settings, 'GROUPMANAGEMENT_AUTO_LEAVE', False)
+        and not GroupRequest.objects.filter(leave_request=True).exists()
+    )
+
     render_items = {
         'acceptrequests': acceptrequests,
         'leaverequests': leaverequests,
-        'auto_leave': getattr(settings, 'GROUPMANAGEMENT_AUTO_LEAVE', False),
+        'show_leave_tab': show_leave_tab,
     }
 
     return render(request, 'groupmanagement/index.html', context=render_items)
@@ -87,7 +90,7 @@ def group_membership_audit(request, group_id):
 
     except ObjectDoesNotExist:
         raise Http404("Group does not exist")
-    render_items = {'group': group.name}
+    render_items = {'group': group}
     entries = RequestLog.objects.filter(group=group).order_by('-date')
     render_items['entries'] = entries
 
@@ -311,8 +314,10 @@ def groups_view(request):
     groups_qs = GroupManager.get_joinable_groups_for_user(
         request.user, include_hidden=False
     )
-    groups_qs = groups_qs.order_by('name')
+    groups_qs = groups_qs.order_by('name').select_related("authgroup").prefetch_related('authgroup__group_leaders', 'authgroup__group_leaders__profile__main_character', 'authgroup__group_leader_groups')
     groups = []
+
+    ## TODO see about making this faster
     for group in groups_qs:
         group_request = GroupRequest.objects\
             .filter(user=request.user)\
@@ -322,7 +327,14 @@ def groups_view(request):
             'request': group_request[0] if group_request else None
         })
 
-    context = {'groups': groups}
+    count = 0
+    perms = GroupManager.can_manage_groups(request.user)
+    if perms:
+        count = GroupManager.pending_requests_count_for_user(request.user)
+
+    user_groups_list = list(request.user.groups.all())
+    context = {'groups': groups, "manager_perms": perms, "req_count":count, "user_groups": user_groups_list}
+
     return render(request, 'groupmanagement/groups.html', context=context)
 
 
@@ -408,3 +420,42 @@ def group_request_leave(request, group_id):
     grouprequest.notify_leaders()
     messages.success(request, _('Applied to leave group %(group)s.') % {"group": group})
     return redirect("groupmanagement:groups")
+
+@login_required
+def group_request_retract(request, group_id):
+    logger.debug(
+        f"group_request_retract called by user {request.user} for group id {group_id}"
+    )
+    group = get_object_or_404(Group, id=group_id)
+
+    if not GroupManager.check_internal_group(group):
+        logger.warning(
+            f"User {request.user} attempted to retract group request for "
+            f"group id {group_id} but it is not a joinable group"
+        )
+        messages.warning(
+            request,
+            _("You cannot retract that request"),
+        )
+        return redirect('groupmanagement:groups')
+
+    try:
+        group_request = GroupRequest.objects.get(
+            user=request.user, group=group, leave_request=False
+        )
+        group_request.delete()
+
+        logger.info(f"Deleted group request for user {request.user} to group {group}")
+        messages.success(
+            request, _('Retracted application to group %(group)s.') % {"group": group}
+        )
+    except GroupRequest.DoesNotExist:
+        logger.info(
+            f"{request.user} attempted to retract group request for "
+            f"group id {group_id} but has no open request"
+        )
+        messages.warning(
+            request, _("You have no open request for that group.")
+        )
+
+    return redirect("groupmanagement:groups")
