@@ -1,7 +1,8 @@
 from django.utils.translation import gettext_lazy as _
 
 from allianceauth import hooks
-from allianceauth.services.hooks import MenuItemHook, UrlHook
+from allianceauth.menu.hooks import MenuItemHook
+from allianceauth.services.hooks import UrlHook
 
 from . import urls
 from .models import Application
@@ -12,7 +13,7 @@ class ApplicationsMenu(MenuItemHook):
         MenuItemHook.__init__(
             self,
             _('Applications'),
-            'far fa-file fa-fw',
+            'fa-regular fa-file',
             'hrapplications:index',
             navactive=['hrapplications:'])
 
