@@ -3,6 +3,7 @@ Form Widgets
 """
 
 from django import forms
+from django.utils.safestring import mark_safe
 
 
 class DataListWidget(forms.TextInput):
@@ -42,4 +43,4 @@ class DataListWidget(forms.TextInput):
 
         data_list += "</datalist>"
 
-        return text_html + data_list
+        return mark_safe(text_html + data_list)
