@@ -1,7 +1,8 @@
+from allianceauth.menu.hooks import MenuItemHook
 from . import urls
 
 from allianceauth import hooks
-from allianceauth.services.hooks import MenuItemHook, UrlHook
+from allianceauth.services.hooks import UrlHook
 
 
 class PermissionsTool(MenuItemHook):
@@ -9,7 +10,7 @@ class PermissionsTool(MenuItemHook):
         MenuItemHook.__init__(
             self,
             'Permissions Audit',
-            'fas fa-id-card fa-fw',
+            'fa-solid fa-id-card',
             'permissions_tool:overview',
             order=400,
             navactive=['permissions_tool:']
