@@ -34,7 +34,7 @@ class AbstractServiceModel(models.Model):
                                 )
 
     def __init__(self, *args, **kwargs):
-        super(AbstractServiceModel, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.credentials = OrderedDict()
         # Should be set with a dict of service credentials (username, password etc) when changed
 
@@ -65,15 +65,14 @@ class ServiceCredentialsViewMixin:
 
 class BaseCreatePasswordServiceAccountView(BaseServiceView, ServiceCredentialsViewMixin):
     def get(self, request):
-        logger.debug("{} called by user {}".format(self.__class__.__name__, request.user))
+        logger.debug(f"{self.__class__.__name__} called by user {request.user}")
         try:
             svc_obj = self.model.objects.create(user=request.user)
         except IntegrityError:
             messages.error(request, _("That service account already exists"))
             return redirect(self.index_redirect)
 
-        return render(request, self.template_name,
-                      context={'credentials': svc_obj.credentials, 'service': self.service_name, 'view': self})
+        return render(request, self.template_name, context={'credentials': svc_obj.credentials, 'service': self.service_name, 'view': self})
 
 
 class ServicesCRUDMixin(SingleObjectMixin):
@@ -99,9 +98,12 @@ class BaseSetPasswordServiceAccountView(ServicesCRUDMixin, BaseServiceView, Upda
     form_class = ServicePasswordModelForm  # You should overload this with a subclass
 
     def post(self, request, *args, **kwargs):
-        result = super(BaseSetPasswordServiceAccountView, self).post(request, *args, **kwargs)
+        result = super().post(request, *args, **kwargs)
         if self.get_form().is_valid():
-            messages.success(request, _("Successfully set your {} password".format(self.service_name)))
+            messages.success(
+                request,
+                _("Successfully set your {service_name} password").format(service_name=self.service_name)
+            )
         return result
 
 
@@ -112,5 +114,4 @@ class BaseResetPasswordServiceAccountView(ServicesCRUDMixin, BaseServiceView, Se
     def get(self, request):
         svc_obj = self.get_object()
         svc_obj.reset_password()
-        return render(request, self.template_name,
-                      context={'credentials': svc_obj.credentials, 'service': self.service_name, 'view': self})
+        return render(request, self.template_name, context={'credentials': svc_obj.credentials, 'service': self.service_name, 'view': self})
