@@ -1,15 +1,23 @@
-from django.conf.urls import include
-from django.urls import re_path
+from string import Formatter
+from django.urls import include, re_path
+from typing import Iterable, Optional
+
+from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
 from django.template.loader import render_to_string
+from django.urls import include, re_path
 from django.utils.functional import cached_property
-from django.conf import settings
-from string import Formatter
 
 from allianceauth.hooks import get_hooks
+from allianceauth.menu.hooks import MenuItemHook
+from django.conf import settings
+from django.urls import include, re_path
+from django.core.exceptions import ObjectDoesNotExist
+from django.utils.functional import cached_property
 
 from .models import NameFormatConfig
 
+
 def get_extension_logger(name):
     """
     Takes the name of a plugin/extension and generates a child logger of the extensions logger
@@ -133,31 +141,44 @@ class ServicesHook:
             yield fn()
 
 
-class MenuItemHook:
-    def __init__(self, text, classes, url_name, order=None, navactive=list([])):
-        self.text = text
-        self.classes = classes
-        self.url_name = url_name
-        self.template = 'public/menuitem.html'
-        self.order = order if order is not None else 9999
+class MenuItemHook(MenuItemHook):
+    """
+    MenuItemHook shim to allianceauth.menu.hooks
 
-        # count is an integer shown next to the menu item as badge when count != None
-        # apps need to set the count in their child class, e.g. in render() method
-        self.count = None
-
-        navactive = navactive or []
-        navactive.append(url_name)
-        self.navactive = navactive
-
-    def render(self, request):
-        return render_to_string(self.template,
-                                {'item': self},
-                                request=request)
+    :param MenuItemHook: _description_
+    :type MenuItemHook: _type_
+    """
+    def __init_subclass__(cls) -> None:
+        return super().__init_subclass__()
 
 
 class UrlHook:
-    def __init__(self, urls, namespace, base_url):
+    """A hook for registering the URLs of a Django app.
+
+    Args:
+        - urls: The urls module to include
+        - namespace: The URL namespace to apply. This is usually just the app name.
+        - base_url: The URL prefix to match against in regex form.
+            Example ``r'^app_name/'``.
+            This prefix will be applied in front of all URL patterns included.
+            It is possible to use the same prefix as existing apps (or no prefix at all),
+            but standard URL resolution ordering applies
+            (hook URLs are the last ones registered).
+        - excluded_views: Optional list of views to be excluded
+            from auto-decorating them with the
+            default ``main_character_required`` decorator, e.g. to make them public.
+            Views must be specified by their qualified name,
+            e.g. ``["example.views.my_public_view"]``
+    """
+    def __init__(
+            self,
+            urls,
+            namespace: str,
+            base_url: str,
+            excluded_views : Optional[Iterable[str]] = None
+    ):
         self.include_pattern = re_path(base_url, include(urls, namespace=namespace))
+        self.excluded_views = set(excluded_views or [])
 
 
 class NameFormatter:
