@@ -16,8 +16,7 @@ from redis import Redis
 
 from allianceauth.utils.cache import get_redis_client
 
-from allianceauth import __title__ as AUTH_TITLE
-from allianceauth import __url__, __version__
+from allianceauth import __title_useragent__, __url__, __version__
 
 from .. import __title__
 from ..utils import LoggerAddTag
@@ -588,16 +587,17 @@ class DiscordClient:
             return None  # User is no longer a member
         guild_roles = RolesSet(self.guild_roles(guild_id=guild_id))
         logger.debug('Current guild roles: %s', guild_roles.ids())
+        _roles = set(member_info.roles)
         if not guild_roles.has_roles(member_info.roles):
             guild_roles = RolesSet(
                 self.guild_roles(guild_id=guild_id, use_cache=False)
             )
             if not guild_roles.has_roles(member_info.roles):
                 role_ids = set(member_info.roles).difference(guild_roles.ids())
-                raise RuntimeError(
-                    f'Discord user {user_id} has unknown roles: {role_ids}'
-                )
-        return guild_roles.subset(member_info.roles)
+                logger.warning(f'Discord user {user_id} has unknown roles: {role_ids}')
+                for _r in role_ids:
+                    _roles.remove(_r)
+        return guild_roles.subset(_roles)
 
     @classmethod
     def _is_member_unknown_error(cls, r: requests.Response) -> bool:
@@ -646,7 +646,7 @@ class DiscordClient:
         if self.is_rate_limited:
             self._ensure_rate_limed_not_exhausted(uid)
         headers = {
-            'User-Agent': f'{AUTH_TITLE} ({__url__}, {__version__})',
+            'User-Agent': f'{__title_useragent__}/{__version__} (+{__url__})',
             'accept': 'application/json',
             'X-RateLimit-Precision': 'millisecond',
             'authorization': str(authorization)
@@ -674,10 +674,12 @@ class DiscordClient:
         )
         logger.debug('%s: response:\n%s', uid, r.text)
         if not r.ok:
-            logger.warning(
-                '%s: Discord API returned error code %d and this response: %s',
+            member_id = url.split("/")[-1]
+            logger.error(
+                '%s: Discord API returned error code %d for member ID %s with this response: %s.',
                 uid,
                 r.status_code,
+                member_id,
                 r.text
             )
 
