@@ -7,8 +7,7 @@ import requests_mock
 from redis import Redis
 from requests.exceptions import HTTPError
 
-from allianceauth import __title__ as AUTH_TITLE
-from allianceauth import __url__, __version__
+from allianceauth import __title_useragent__, __url__, __version__
 from allianceauth.utils.testing import NoSocketsTestCase
 
 from ...utils import set_logger_to_file
@@ -46,7 +45,7 @@ API_BASE_URL = 'https://discord.com/api/'
 TEST_RETRY_AFTER = 3000
 
 DEFAULT_REQUEST_HEADERS = {
-    'User-Agent': f'{AUTH_TITLE} ({__url__}, {__version__})',
+    'User-Agent': f'{__title_useragent__}/{__version__} (+{__url__})',
     'accept': 'application/json',
     'authorization': 'Bot ' + TEST_BOT_TOKEN
 }
@@ -899,8 +898,8 @@ class TestGuildMemberRoles(NoSocketsTestCase):
         mock_guild_roles.return_value = {role_a, role_b}
         client = DiscordClientStub(TEST_BOT_TOKEN, mock_redis)
         # when/then
-        with self.assertRaises(RuntimeError):
-            client.guild_member_roles(TEST_GUILD_ID, TEST_USER_ID)
+        roles = client.guild_member_roles(TEST_GUILD_ID, TEST_USER_ID)
+        self.assertEqual(roles, RolesSet([role_a]))
 
     # TODO: Re-enable after adding Discord general error handling
     # def test_should_raise_exception_if_member_info_is_invalid(
