@@ -1,5 +1,6 @@
 import random
 import string
+from typing import ClassVar
 from passlib.hash import bcrypt_sha256
 
 from django.db import models
@@ -62,6 +63,12 @@ class MumbleManager(models.Manager):
 
 
 class MumbleUser(AbstractServiceModel):
+    user = models.OneToOneField(
+        'auth.User',
+        primary_key=True,
+        on_delete=models.CASCADE,
+        related_name='mumble'
+    )
     username = models.CharField(max_length=254, unique=True)
     pwhash = models.CharField(max_length=90)
     hashfn = models.CharField(max_length=20, default='sha1')
@@ -84,7 +91,7 @@ class MumbleUser(AbstractServiceModel):
         blank=True,
         null=True,
         editable=False,
-        help_text="The Mumble Release the user last authenticated with"
+        help_text="Client release. For official releases, this equals the version. For snapshots and git compiles, this will be something else."
     )
     version = models.IntegerField(
         verbose_name="Mumble Version",
@@ -110,7 +117,7 @@ class MumbleUser(AbstractServiceModel):
         help_text="Timestamp of the users Last Disconnection to Mumble"
     )
 
-    objects = MumbleManager()
+    objects: ClassVar[MumbleManager] = MumbleManager()
 
     def __str__(self):
         return self.username
@@ -153,4 +160,5 @@ class MumbleUser(AbstractServiceModel):
     class Meta:
         permissions = (
             ("access_mumble", "Can access the Mumble service"),
+            ("view_connection_history", "Can access the connection history of the Mumble service"),
         )
