@@ -1,5 +1,4 @@
-from django.conf.urls import include
-from django.urls import path
+from django.urls import include, path
 
 from . import views
 
@@ -11,6 +10,10 @@ module_urls = [
     path('deactivate/', views.DeleteMumbleView.as_view(), name='deactivate'),
     path('reset_password/', views.ResetPasswordMumbleView.as_view(), name='reset_password'),
     path('set_password/', views.SetPasswordMumbleView.as_view(), name='set_password'),
+    path('connection_history/', views.connection_history, name="connection_history"),
+    path('ajax/connection_history_data', views.connection_history_data, name="connection_history_data"),
+    path('ajax/release_counts_data', views.release_counts_data, name="release_counts_data"),
+    path('ajax/release_pie_chart_data', views.release_pie_chart_data, name="release_pie_chart_data"),
 ]
 
 urlpatterns = [
