@@ -24,23 +24,23 @@ ACCESS_PERM = 'openfire.access_openfire'
 def activate_jabber(request):
     logger.debug("activate_jabber called by user %s" % request.user)
     character = request.user.profile.main_character
-    logger.debug(f"Adding jabber user for user {request.user} with main character {character}")
+    logger.debug(f"Adding Jabber user for user {request.user} with main character {character}")
     info = OpenfireManager.add_user(OpenfireTasks.get_username(request.user))
     # If our username is blank means we already had a user
     if info[0] != "":
         OpenfireUser.objects.update_or_create(user=request.user, defaults={'username': info[0]})
-        logger.debug("Updated authserviceinfo for user %s with jabber credentials. Updating groups." % request.user)
+        logger.debug("Updated authserviceinfo for user %s with Jabber credentials. Updating groups." % request.user)
         OpenfireTasks.update_groups.delay(request.user.pk)
-        logger.info("Successfully activated jabber for user %s" % request.user)
-        messages.success(request, _('Activated jabber account.'))
+        logger.info("Successfully activated Jabber for user %s" % request.user)
+        messages.success(request, _('Activated Jabber account.'))
         credentials = {
             'username': info[0],
             'password': info[1],
         }
         return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'Jabber'})
     else:
-        logger.error("Unsuccessful attempt to activate jabber for user %s" % request.user)
-        messages.error(request, _('An error occurred while processing your jabber account.'))
+        logger.error("Unsuccessful attempt to activate Jabber for user %s" % request.user)
+        messages.error(request, _('An error occurred while processing your Jabber account.'))
     return redirect("services:services")
 
 
@@ -49,11 +49,11 @@ def activate_jabber(request):
 def deactivate_jabber(request):
     logger.debug("deactivate_jabber called by user %s" % request.user)
     if OpenfireTasks.has_account(request.user) and OpenfireTasks.delete_user(request.user):
-        logger.info("Successfully deactivated jabber for user %s" % request.user)
-        messages.success(request, 'Deactivated jabber account.')
+        logger.info("Successfully deactivated Jabber for user %s" % request.user)
+        messages.success(request, 'Deactivated Jabber account.')
     else:
-        logger.error("Unsuccessful attempt to deactivate jabber for user %s" % request.user)
-        messages.error(request, _('An error occurred while processing your jabber account.'))
+        logger.error("Unsuccessful attempt to deactivate Jabber for user %s" % request.user)
+        messages.error(request, _('An error occurred while processing your Jabber account.'))
     return redirect("services:services")
 
 
@@ -65,15 +65,15 @@ def reset_jabber_password(request):
         result = OpenfireManager.update_user_pass(request.user.openfire.username)
         # If our username is blank means we failed
         if result != "":
-            logger.info("Successfully reset jabber password for user %s" % request.user)
-            messages.success(request, _('Reset jabber password.'))
+            logger.info("Successfully reset Jabber password for user %s" % request.user)
+            messages.success(request, _('Reset Jabber password.'))
             credentials = {
                 'username': request.user.openfire.username,
                 'password': result,
             }
             return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'Jabber'})
-    logger.error("Unsuccessful attempt to reset jabber for user %s" % request.user)
-    messages.error(request, _('An error occurred while processing your jabber account.'))
+    logger.error("Unsuccessful attempt to reset Jabber for user %s" % request.user)
+    messages.error(request, _('An error occurred while processing your Jabber account.'))
     return redirect("services:services")
 
 
@@ -95,25 +95,25 @@ def jabber_broadcast_view(request):
         logger.debug("Received POST request containing form, valid: %s" % form.is_valid())
         if form.is_valid():
             main_char = request.user.profile.main_character
-            logger.debug(f"Processing jabber broadcast for user {request.user} with main character {main_char}")
+            logger.debug(f"Processing Jabber broadcast for user {request.user} with main character {main_char}")
             try:
                 if main_char is not None:
                     message_to_send = form.cleaned_data['message'] + "\n##### SENT BY: " + "[" + main_char.corporation_ticker + "]" + \
                                         main_char.character_name + " TO: " + \
-                                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.utcnow().strftime(
+                                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.now(datetime.timezone.utc).strftime(
                                             "%Y-%m-%d %H:%M:%S") + " #####\n##### Replies are NOT monitored #####\n"
                     group_to_send = form.cleaned_data['group']
 
                 else:
                     message_to_send = form.cleaned_data['message'] + "\n##### SENT BY: " + "No character but can send pings?" + " TO: " + \
-                                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.utcnow().strftime(
+                                        form.cleaned_data['group'] + " WHEN: " + datetime.datetime.now(datetime.timezone.utc).strftime(
                                             "%Y-%m-%d %H:%M:%S") + " #####\n##### Replies are NOT monitored #####\n"
                     group_to_send = form.cleaned_data['group']
 
                 OpenfireManager.send_broadcast_message(group_to_send, message_to_send)
 
-                messages.success(request, _('Sent jabber broadcast to %s' % group_to_send))
-                logger.info("Sent jabber broadcast on behalf of user %s" % request.user)
+                messages.success(request, _('Sent Jabber broadcast to %s' % group_to_send))
+                logger.info("Sent Jabber broadcast on behalf of user %s" % request.user)
             except PingBotException as e:
                 messages.error(request, e)
 
@@ -140,11 +140,11 @@ def set_jabber_password(request):
             logger.debug("Form contains password of length %s" % len(password))
             result = OpenfireManager.update_user_pass(request.user.openfire.username, password=password)
             if result != "":
-                logger.info("Successfully set jabber password for user %s" % request.user)
+                logger.info("Successfully set Jabber password for user %s" % request.user)
                 messages.success(request, _('Set jabber password.'))
             else:
-                logger.error("Failed to install custom jabber password for user %s" % request.user)
-                messages.error(request, _('An error occurred while processing your jabber account.'))
+                logger.error("Failed to install custom Jabber password for user %s" % request.user)
+                messages.error(request, _('An error occurred while processing your Jabber account.'))
             return redirect("services:services")
     else:
         logger.debug("Request is not type POST - providing empty form.")
