@@ -2,7 +2,7 @@ import random
 import string
 import calendar
 import re
-from datetime import datetime
+import datetime as dt
 
 from passlib.apps import phpbb3_context
 from django.db import connections
@@ -128,7 +128,7 @@ class Phpbb3Manager:
 
     @staticmethod
     def __get_current_utc_date():
-        d = datetime.utcnow()
+        d = dt.datetime.now(dt.timezone.utc)
         unixtime = calendar.timegm(d.utctimetuple())
         return unixtime
 
@@ -176,7 +176,7 @@ class Phpbb3Manager:
         logger.debug(f"Proceeding to add phpbb user {username_clean} and pwhash starting with {pwhash[0:5]}")
         # check if the username was simply revoked
         if Phpbb3Manager.check_user(username_clean):
-            logger.warn("Unable to add phpbb user with username %s - already exists. Updating user instead." % username)
+            logger.warning("Unable to add phpbb user with username %s - already exists. Updating user instead." % username)
             Phpbb3Manager.__update_user_info(username_clean, email, pwhash)
         else:
             try:
