@@ -22,7 +22,7 @@ def activate_forum(request):
     logger.debug("activate_forum called by user %s" % request.user)
     # Valid now we get the main characters
     character = request.user.profile.main_character
-    logger.debug("Adding phpbb user for user %s with main character %s" % (request.user, character))
+    logger.debug(f"Adding phpbb user for user {request.user} with main character {character}")
     result = Phpbb3Manager.add_user(Phpbb3Tasks.get_username(request.user), request.user.email, ['REGISTERED'],
                                     character.character_id)
     # if empty we failed
@@ -36,8 +36,7 @@ def activate_forum(request):
             'username': result[0],
             'password': result[1],
         }
-        return render(request, 'services/service_credentials.html',
-                      context={'credentials': credentials, 'service': 'Forum'})
+        return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'Forum'})
     else:
         logger.error("Unsuccessful attempt to activate forum for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your forum account.'))
@@ -73,8 +72,7 @@ def reset_forum_password(request):
                 'username': request.user.phpbb3.username,
                 'password': result,
             }
-            return render(request, 'services/service_credentials.html',
-                          context={'credentials': credentials, 'service': 'Forum'})
+            return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'Forum'})
 
     logger.error("Unsuccessful attempt to reset forum password for user %s" % request.user)
     messages.error(request, _('An error occurred while processing your forum account.'))
