@@ -24,7 +24,7 @@ def activate_smf(request):
     main_character = request.user.profile.main_character
 
     logger.debug(
-        f"Adding smf user for user {request.user} with main character {main_character}"
+        f"Adding SMF user for user {request.user} with main character {main_character}"
     )
 
     result = SmfManager.add_user(
@@ -42,12 +42,12 @@ def activate_smf(request):
 
         logger.debug(
             f"Updated authserviceinfo for user {request.user} "
-            f"with smf credentials. Updating groups."
+            f"with SMF credentials. Updating groups."
         )
 
         SmfTasks.update_groups.delay(request.user.pk)
 
-        logger.info(f"Successfully activated smf for user {request.user}")
+        logger.info(f"Successfully activated SMF for user {request.user}")
 
         messages.success(request, _('Activated SMF account.'))
         credentials = {
@@ -61,7 +61,7 @@ def activate_smf(request):
             context={'credentials': credentials, 'service': 'SMF'},
         )
 
-    logger.error(f"Unsuccessful attempt to activate smf for user {request.user}")
+    logger.error(f"Unsuccessful attempt to activate SMF for user {request.user}")
     messages.error(request, _('An error occurred while processing your SMF account.'))
 
     return redirect("services:services")
@@ -74,10 +74,10 @@ def deactivate_smf(request):
     result = SmfTasks.delete_user(request.user)
     # false we failed
     if result:
-        logger.info("Successfully deactivated smf for user %s" % request.user)
+        logger.info("Successfully deactivated SMF for user %s" % request.user)
         messages.success(request, _('Deactivated SMF account.'))
     else:
-        logger.error("Unsuccessful attempt to activate smf for user %s" % request.user)
+        logger.error("Unsuccessful attempt to activate SMF for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your SMF account.'))
     return redirect("services:services")
 
@@ -91,14 +91,14 @@ def reset_smf_password(request):
         result = SmfManager.update_user_password(request.user.smf.username, character.character_id)
         # false we failed
         if result != "":
-            logger.info("Successfully reset smf password for user %s" % request.user)
+            logger.info("Successfully reset SMF password for user %s" % request.user)
             messages.success(request, _('Reset SMF password.'))
             credentials = {
                 'username': request.user.smf.username,
                 'password': result,
             }
             return render(request, 'services/service_credentials.html', context={'credentials': credentials, 'service': 'SMF'})
-    logger.error("Unsuccessful attempt to reset smf password for user %s" % request.user)
+    logger.error("Unsuccessful attempt to reset SMF password for user %s" % request.user)
     messages.error(request, _('An error occurred while processing your SMF account.'))
     return redirect("services:services")
 
@@ -117,10 +117,10 @@ def set_smf_password(request):
             logger.debug("Form contains password of length %s" % len(password))
             result = SmfManager.update_user_password(request.user.smf.username, character.character_id, password=password)
             if result != "":
-                logger.info("Successfully set smf password for user %s" % request.user)
+                logger.info("Successfully set SMF password for user %s" % request.user)
                 messages.success(request, _('Set SMF password.'))
             else:
-                logger.error("Failed to install custom smf password for user %s" % request.user)
+                logger.error("Failed to install custom SMF password for user %s" % request.user)
                 messages.error(request, _('An error occurred while processing your SMF account.'))
             return redirect("services:services")
     else:
