@@ -454,20 +454,16 @@ request.user = MockSuperUser()
 class Teamspeak3AdminTestCase(TestCase):
     @classmethod
     def setUpTestData(cls):
-        cls.site = AdminSite()
-        cls.admin = AuthTSgroupAdmin(AuthTS, cls.site)
         cls.group = Group.objects.create(name='test')
-        cls.ts_group = TSgroup.objects.create(ts_group_name='test')
+        cls.ts_group = TSgroup.objects.create(ts_group_id=1, ts_group_name='test')
 
     def test_field_queryset_no_reserved_names(self):
         """Ensure all groups are listed when no reserved names"""
-        form = self.admin.get_form(request)
-        self.assertQuerysetEqual(form.base_fields['auth_group']._get_queryset(), Group.objects.all())
-        self.assertQuerysetEqual(form.base_fields['ts_group']._get_queryset(), TSgroup.objects.all())
+        self.assertQuerySetEqual(AuthTSgroupAdmin(AuthTS, AdminSite()).get_form(request).base_fields['auth_group']._get_queryset(), Group.objects.all())
+        self.assertQuerySetEqual(AuthTSgroupAdmin(AuthTS, AdminSite()).get_form(request).base_fields['ts_group']._get_queryset(), TSgroup.objects.all())
 
     def test_field_queryset_reserved_names(self):
         """Ensure reserved group names are filtered out"""
         ReservedGroupName.objects.bulk_create([ReservedGroupName(name='test', reason='tests', created_by='Bob')])
-        form = self.admin.get_form(request)
-        self.assertQuerysetEqual(form.base_fields['auth_group']._get_queryset(), Group.objects.none())
-        self.assertQuerysetEqual(form.base_fields['ts_group']._get_queryset(), TSgroup.objects.none())
+        self.assertQuerySetEqual(AuthTSgroupAdmin(AuthTS, AdminSite()).get_form(request).base_fields['auth_group']._get_queryset(), Group.objects.none())
+        self.assertQuerySetEqual(AuthTSgroupAdmin(AuthTS, AdminSite()).get_form(request).base_fields['ts_group']._get_queryset(), TSgroup.objects.none())
