@@ -36,7 +36,7 @@ def activate_xenforo_forum(request):
                         context={'credentials': credentials, 'service': 'XenForo'})
 
     else:
-        logger.error("Unsuccessful attempt to activate xenforo for user %s" % request.user)
+        logger.error("Unsuccessful attempt to activate XenForo for user %s" % request.user)
         messages.error(request, _('An error occurred while processing your XenForo account.'))
     return redirect("services:services")
 
