@@ -3,32 +3,50 @@ from unittest import mock
 from celery_once import AlreadyQueued
 
 from django.core.cache import cache
-from django.test import TestCase
+from django.test import override_settings, TestCase
 
 from allianceauth.tests.auth_utils import AuthUtils
-from allianceauth.services.tasks import validate_services
+from allianceauth.services.tasks import validate_services, update_groups_for_user
 
 from ..tasks import DjangoBackend
 
 
+@override_settings(CELERY_ALWAYS_EAGER=True, CELERY_EAGER_PROPAGATES_EXCEPTIONS=True)
 class ServicesTasksTestCase(TestCase):
     def setUp(self):
         self.member = AuthUtils.create_user('auth_member')
 
     @mock.patch('allianceauth.services.tasks.ServicesHook')
     def test_validate_services(self, services_hook):
+        # given
         svc = mock.Mock()
         svc.validate_user.return_value = None
-
         services_hook.get_services.return_value = [svc]
-
+        # when
         validate_services.delay(self.member.pk)
-
+        # then
         self.assertTrue(services_hook.get_services.called)
         self.assertTrue(svc.validate_user.called)
-        args, kwargs = svc.validate_user.call_args
+        args, _ = svc.validate_user.call_args
         self.assertEqual(self.member, args[0])  # Assert correct user is passed to service hook function
 
+    @mock.patch('allianceauth.services.tasks.ServicesHook')
+    def test_update_groups_for_user(self, services_hook):
+        # given
+        svc = mock.Mock()
+        svc.validate_user.return_value = None
+        services_hook.get_services.return_value = [svc]
+        # when
+        update_groups_for_user.delay(self.member.pk)
+        # then
+        self.assertTrue(services_hook.get_services.called)
+        self.assertTrue(svc.validate_user.called)
+        args, _ = svc.validate_user.call_args
+        self.assertEqual(self.member, args[0])  # Assert correct user
+        self.assertTrue(svc.update_groups.called)
+        args, _ = svc.update_groups.call_args
+        self.assertEqual(self.member, args[0])  # Assert correct user
+
 
 class TestDjangoBackend(TestCase):
 
