@@ -1,4 +1,4 @@
-from django.conf.urls import include
+from django.urls import include
 from allianceauth.hooks import get_hooks
 from django.urls import path
 
