@@ -1,7 +1,8 @@
 from django.utils.translation import gettext_lazy as _
 
 from allianceauth import hooks
-from allianceauth.services.hooks import MenuItemHook, UrlHook
+from allianceauth.menu.hooks import MenuItemHook
+from allianceauth.services.hooks import UrlHook
 
 from . import urls
 from .managers import SRPManager
@@ -11,7 +12,7 @@ class SrpMenu(MenuItemHook):
     def __init__(self):
         MenuItemHook.__init__(
             self, _('Ship Replacement'),
-            'far fa-money-bill-alt fa-fw',
+            'fa-regular fa-money-bill-1',
             'srp:management',
             navactive=['srp:']
         )
