@@ -1,20 +1,22 @@
-$(document).ready(function () {
+$(document).ready(() => {
     'use strict';
 
     /**
-     * render a JS clock for Eve Time
+     * Render the current EVE time in the top menu bar
      * @param element
      */
-    const renderClock = function (element) {
+    const renderClock = (element) => {
         const datetimeNow = new Date();
         const h = String(datetimeNow.getUTCHours()).padStart(2, '0');
         const m = String(datetimeNow.getUTCMinutes()).padStart(2, '0');
 
-        element.html(h + ':' + m);
+        element.html(`${h}:${m}`);
     };
 
-    // Start the Eve time clock in the top menu bar
-    setInterval(function () {
+    /**
+     * Start the EVE time clock in the top menu bar
+     */
+    setInterval(() => {
         renderClock($('.eve-time-wrapper .eve-time-clock'));
     }, 500);
 });
