@@ -1,19 +1,16 @@
 import logging
-from typing import Optional
 
-import amqp.exceptions
 import requests
-from celery.app import app_or_default
-from packaging.version import InvalidVersion
-from packaging.version import Version as Pep440Version
+from packaging.version import InvalidVersion, Version as Pep440Version
 
 from django import template
 from django.conf import settings
 from django.core.cache import cache
 
 from allianceauth import __version__
-
-from ..authentication.task_statistics.counters import dashboard_results
+from allianceauth.authentication.task_statistics.counters import (
+    dashboard_results,
+)
 
 register = template.Library()
 
@@ -41,7 +38,7 @@ def decimal_widthratio(this_value, max_value, max_width) -> str:
     if max_value == 0:
         return str(0)
 
-    return str(round(this_value/max_value * max_width, 2))
+    return str(round(this_value / max_value * max_width, 2))
 
 
 @register.inclusion_tag('allianceauth/admin-status/overview.html')
@@ -49,17 +46,16 @@ def status_overview() -> dict:
     response = {
         "notifications": list(),
         "current_version": __version__,
-        "task_queue_length": None,
         "tasks_succeeded": 0,
         "tasks_retried": 0,
         "tasks_failed": 0,
         "tasks_total": 0,
         "tasks_hours": 0,
-        "earliest_task": None
+        "earliest_task": None,
+        "debug": settings.DEBUG if settings.DISPLAY_DEBUG else False,
     }
     response.update(_current_notifications())
     response.update(_current_version_summary())
-    response.update({'task_queue_length': _fetch_celery_queue_length()})
     response.update(_celery_stats())
     return response
 
@@ -73,27 +69,10 @@ def _celery_stats() -> dict:
         "tasks_failed": results.failed,
         "tasks_total": results.total,
         "tasks_hours": results.hours,
-        "earliest_task": results.earliest_task
+        "earliest_task": results.earliest_task,
     }
 
 
-def _fetch_celery_queue_length() -> Optional[int]:
-    try:
-        app = app_or_default(None)
-        with app.connection_or_acquire() as conn:
-            result = conn.default_channel.queue_declare(
-                queue=getattr(settings, 'CELERY_DEFAULT_QUEUE', 'celery'),
-                passive=True
-            )
-            return result.message_count
-    except amqp.exceptions.ChannelError:
-        # Queue doesn't exist, probably empty
-        return 0
-    except Exception:
-        logger.exception("Failed to get celery queue length")
-    return None
-
-
 def _current_notifications() -> dict:
     """returns the newest 5 announcement issues"""
     try:
