@@ -98,7 +98,7 @@ class TimerboardViewsTestCase(WebTest):
 
         response = self.app.get(self.view_url)
 
-        context = response.context[-1]
+        context = response.context
 
         timers = context['timers']
         corp_timers = context['corp_timers']
@@ -167,8 +167,8 @@ class TimerboardViewsTestCase(WebTest):
         form['details'] = 'details'
         form['system'] = 'jita'
         form['planet_moon'] = '4-4'
-        form['structure'] = TimerForm.structure_choices[0][0]
-        form['objective'] = TimerForm.objective_choices[0][0]
+        form['structure'] = Timer.Structure.choices[0][0]
+        form['objective'] = Timer.Objective.choices[0][0]
         form['days_left'] = 1
         form['hours_left'] = 2
         form['minutes_left'] = 3
@@ -206,8 +206,8 @@ class TimerboardViewsTestCase(WebTest):
         form['details'] = 'detailsUNIQUE'
         form['system'] = 'jita'
         form['planet_moon'] = '4-4'
-        form['structure'] = TimerForm.structure_choices[0][0]
-        form['objective'] = TimerForm.objective_choices[0][0]
+        form['structure'] = Timer.Structure.choices[0][0]
+        form['objective'] = Timer.Objective.choices[0][0]
         form['days_left'] = 1
         form['hours_left'] = 2
         form['minutes_left'] = 3
